@@ -69,7 +69,8 @@ C    IFA    -  VECTOR OF ERROR INDICATOR FLAGS
       PARAMETER (N1=12,N2=1000,N3=45)
       COMMON NVAR,NVERT,NCON,THETA(N3,N1),XVT(N2,N1),
      +DK(N2,N3),IMIX,TOL1,TOL2
-      CHARACTER*20 FIN
+c      CHARACTER*20 FIN
+      CHARACTER(20) FIN
 	  integer ynr(n3)
       DIMENSION THETA2(N3,N1),RTHETA2(N3*N1),RXVT(N2*N1)
 	  DIMENSION IVRT(N2),IFA(4)
